.. AUTO-GENERATED FILE -- DO NOT EDIT!

models.columns
==============

Module: :mod:`models.columns`
-----------------------------
Inheritance diagram for ``ISLP.models.columns``:

.. inheritance-diagram:: ISLP.models.columns 
   :parts: 3

.. automodule:: ISLP.models.columns

.. currentmodule:: ISLP.models.columns

:class:`Column`
---------------


.. autoclass:: Column
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:

  .. automethod:: __init__
